@@ -1,6 +1,6 @@
 /*
  * prop2.c
- * Copyright (C) 2002,2003 A.J. van Os; Released under GPL
+ * Copyright (C) 2002-2004 A.J. van Os; Released under GPL
  *
  * Description:
  * Read the property information from a WinWord 1 or 2 file
@@ -313,7 +313,6 @@ eGet2RowInfo(int iFodo,
 				werr(1, "The number of columns is corrupt");
 			}
 			pRow->ucNumberOfColumns = (UCHAR)iCol;
-			pRow->iColumnWidthSum = 0;
 			iPosPrev = (int)(short)usGetWord(
 					iFodo + iFodoOff + 4,
 					aucGrpprl);
@@ -323,8 +322,6 @@ eGet2RowInfo(int iFodo,
 					aucGrpprl);
 				pRow->asColumnWidth[iIndex] =
 						(short)(iPosCurr - iPosPrev);
-				pRow->iColumnWidthSum +=
-					pRow->asColumnWidth[iIndex];
 				iPosPrev = iPosCurr;
 			}
 			bFound154 = TRUE;
@@ -395,6 +392,7 @@ vGet2StyleInfo(int iFodo,
 				eGetNumType(ucTmp) == level_type_pause;
 			break;
 		case  15:	/* ChgTabsPapx */
+		case  23:	/* ChgTabs */
 			iTmp = (int)ucGetByte(iFodo + iFodoOff + 1, aucGrpprl);
 			if (iTmp < 2) {
 				iInfoLen = 1;
